@@ -45,9 +45,9 @@ class AuthenticationBlock:
         use_asyncio: bool = False,
         validate_credentials: bool = True,
         log_output: bool = True,
+        raise_structured_exception: bool = False,
     ):
-        """
-        Create an AuthenticationBlock object with the following properties that are useful
+        """Create an AuthenticationBlock object with the following properties that are useful
         externally: host, credentials, api_client, anyscale_api_client.
 
         Arguments:
@@ -57,10 +57,15 @@ class AuthenticationBlock:
             host (Optional[str]): Host address of Anyscale. Default host will be used if not
                 provided.
             use_asyncio (bool): Use asyncio in anyscale external api client.
-            validate_credentials (bool): If set to False, credentials that are passed will not
-                be authenticated against the Anyscale host.
-        `validate_credentials=False` should only be used when writing internal tests, because
-        credentials and the host will not be authenticated against Anyscale if provided.
+            validate_credentials (bool): If set to False, credentials that are
+                passed will not be authenticated against the Anyscale host.
+                `validate_credentials=False` should only be used when writing
+                internal tests, because credentials and the host will not be
+                authenticated against Anyscale if provided.
+            log_output (bool): Whether actions should be logged.
+            raise_structured_exception (bool): Whether to raise a structured
+                exception (python class with fields), or a click exception with a human
+                readable string.
         """
         self.log = BlockLogger(log_output=log_output)
         self.block_label = "Authenticating"
@@ -77,9 +82,9 @@ class AuthenticationBlock:
         if validate_credentials:
             self._validate_credentials_format(self.credentials)
 
-        self.api_client = self._instantiate_api_client()
+        self.api_client = self._instantiate_api_client(raise_structured_exception)
         self.anyscale_api_client = self._instantiate_anyscale_client(
-            use_asyncio=use_asyncio
+            raise_structured_exception, use_asyncio=use_asyncio
         )
         if validate_credentials:
             self._validate_api_client_auth()
@@ -91,38 +96,65 @@ class AuthenticationBlock:
         self._warn_credential_file_permissions(cli_token_location)
         self.log.close_block(self.block_label)
 
-    def _instantiate_api_client(self,) -> DefaultApi:
+    @property
+    def product_api_client(self) -> DefaultApi:
+        # TODO: shawnp. rename the field from api_client to product_api_client
+        return self.api_client
+
+    @property
+    def base_api_client(self) -> AnyscaleApi:
+        # TODO: shawnp. rename the field from anyscale_api_client to base_api_client
+        return self.anyscale_api_client
+
+    def _instantiate_api_client(self, raise_structured_exception: bool) -> DefaultApi:
         """
         Instantiates client to interact with our frontend APIs
+        Args:
+            raise_structured_exception (bool): Whether to raise a structured
+                exception (python class with fields), or a click exception with a human
+                readable string.
         """
         configuration = openapi_client.Configuration(host=self.host)
         configuration.connection_pool_maxsize = 100
 
         cookie = f"cli_token={self.credentials}"
-        api_client = ApiClientWrapperInternal(configuration, cookie=cookie)
+        api_client = ApiClientWrapperInternal(
+            configuration,
+            cookie=cookie,
+            raise_structured_exception=raise_structured_exception,
+        )
         configure_open_api_client_headers(api_client, "CLI")
         configure_tcp_keepalive(api_client)
         api_instance = openapi_client.DefaultApi(api_client)
         return api_instance
 
-    def _instantiate_anyscale_client(self, use_asyncio: bool = False) -> AnyscaleApi:
+    def _instantiate_anyscale_client(
+        self, raise_structured_exception: bool, use_asyncio: bool = False,
+    ) -> AnyscaleApi:
         """
         Instantiates client to interact with our externalized APIs
 
         Arguments:
+            raise_structured_exception (bool): Whether to raise a structured
+                exception (python class with fields), or a click exception with a human
+                readable string.
             use_asyncio (bool): If this flag is set, the client will run requests in
-            a threadpool. Invocations of the api client will return coroutines.
+                a threadpool. Invocations of the api client will return coroutines.
         """
         configuration = anyscale_client.Configuration(host=self.host + "/ext/v0")
         configuration.connection_pool_maxsize = 100
 
         api_client = (
             ApiClientWrapperExternal(
-                configuration, cookie=f"cli_token={self.credentials}"
+                configuration,
+                cookie=f"cli_token={self.credentials}",
+                raise_structured_exception=raise_structured_exception,
             )
             if not use_asyncio
             else AsyncApiClientWrapperExternal(
-                configuration, cookie=f"cli_token={self.credentials}"
+                configuration,
+                cookie=f"cli_token={self.credentials}",
+                raise_structured_exception=raise_structured_exception,
             )
         )
         configure_open_api_client_headers(api_client, "CLI")
@@ -235,6 +267,7 @@ def get_auth_api_client(
     use_asyncio: bool = False,
     validate_credentials: bool = True,
     log_output: bool = True,
+    raise_structured_exception: bool = False,
 ) -> AuthenticationBlock:
     """
     Function to get global AuthenticationBlock object. The AuthenticationBlock will only be
@@ -254,6 +287,7 @@ def get_auth_api_client(
                 use_asyncio=use_asyncio,
                 validate_credentials=validate_credentials,
                 log_output=log_output,
+                raise_structured_exception=raise_structured_exception,
             )
         except Exception as e:
             _auth_api_client = e
