@@ -92,7 +92,6 @@ ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE = {
                 # Volume management
                 "ec2:AttachVolume",
                 "ec2:CreateVolume",
-                "ec2:DeleteVolume",
                 "ec2:DescribeVolumes",
                 # IAMInstanceProfiles
                 "ec2:AssociateIamInstanceProfile",
@@ -100,7 +99,6 @@ ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE = {
                 "ec2:ReplaceIamInstanceProfileAssociation",
                 # Placement groups
                 "ec2:CreatePlacementGroup",
-                "ec2:DeletePlacementGroup",
                 # Address Management
                 "ec2:AllocateAddress",
                 "ec2:ReleaseAddress",
