@@ -32,6 +32,7 @@ def get_cloud_json_from_id(cloud_id: str, api_client: DefaultApi) -> Dict["str",
         "region": cloud.region,
         "credentials": cloud.credentials,
         "config": cloud.config,
+        "state": cloud.state,
     }
 
 
@@ -42,6 +43,8 @@ def get_cloud_id_and_name(
 ) -> Tuple[str, str]:
     if api_client is None:
         api_client = get_auth_api_client().api_client
+    if not cloud_id and not cloud_name:
+        raise ClickException("Must either provide the cloud name or cloud id.")
     if cloud_id and cloud_name:
         raise ClickException(
             "Both '--cloud-id' and '--cloud-name' specified. Please only use one."
