@@ -1,3 +1,4 @@
+import copy
 import difflib
 import ipaddress
 import pprint
@@ -8,22 +9,23 @@ from typing_extensions import Literal
 from anyscale.aws_iam_policies import (
     AMAZON_ECR_READONLY_ACCESS_POLICY_NAME,
     AMAZON_S3_FULL_ACCESS_POLICY_NAME,
-    ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN,
     ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE,
-    ANYSCALE_IAM_POLICY_NAME_INITIAL_RUN,
-    ANYSCALE_IAM_POLICY_NAME_STEADY_STATE,
     get_anyscale_aws_iam_assume_role_policy,
 )
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models.create_cloud_resource import (
     CreateCloudResource,
 )
-from anyscale.conf import ANYSCALE_IAM_ROLE_NAME
+from anyscale.client.openapi_client.models.subnet_id_with_availability_zone_aws import (
+    SubnetIdWithAvailabilityZoneAWS,
+)
 from anyscale.shared_anyscale_utils.aws import AwsRoleArn
+from anyscale.shared_anyscale_utils.conf import ANYSCALE_HOST
 from anyscale.util import (  # pylint:disable=private-import
     _get_role,
     _get_subnet,
-    get_availability_zones,
+    contains_control_plane_role,
+    get_allow_actions_from_policy_document,
 )
 
 
@@ -123,26 +125,43 @@ def _get_subnets_from_subnet_ids(subnet_ids: List[str], region: str) -> List[Any
 def verify_aws_subnets(
     cloud_resource: CreateCloudResource,
     region: str,
+    is_private_network: bool,
     logger: BlockLogger,
     ignore_capacity_errors: bool = False,  # TODO: Probably don't do this forever. Its kinda hacky
 ) -> Union[
     Tuple[Literal[True], CreateCloudResource],  # Success
     Tuple[Literal[False], Literal[None]],  # Error
 ]:
+    """
+    Verify the subnets cloud resource of a cloud.
+    This function mutates the aws_subnet_ids field in cloud_resource. It combines the subnets with its availability zone.
+    Invariant: After this function, cloud_resource will always have subnet_ids_with_availability_zones instead of aws_subnet_ids.
+    """
     logger.info("Verifying subnets ...")
-    if not cloud_resource.aws_subnet_ids:
-        logger.error("Missing subnet IDs.")
-        return False, None
+    cloud_resource = copy.deepcopy(cloud_resource)
 
     if not cloud_resource.aws_vpc_id:
         logger.error("Missing VPC ID.")
         return False, None
 
-    subnets = _get_subnets_from_subnet_ids(
-        subnet_ids=cloud_resource.aws_subnet_ids, region=region
-    )
+    subnet_ids = []
+    if (
+        cloud_resource.aws_subnet_ids_with_availability_zones
+        and len(cloud_resource.aws_subnet_ids_with_availability_zones) > 0
+    ):
+        subnet_ids = [
+            subnet_id_with_az.subnet_id
+            for subnet_id_with_az in cloud_resource.aws_subnet_ids_with_availability_zones
+        ]
+    elif cloud_resource.aws_subnet_ids and len(cloud_resource.aws_subnet_ids) > 0:
+        subnet_ids = cloud_resource.aws_subnet_ids
+    else:
+        logger.error("Missing subnet IDs.")
+        return False, None
 
-    for subnet, subnet_id in zip(subnets, cloud_resource.aws_subnet_ids):
+    subnets = _get_subnets_from_subnet_ids(subnet_ids=subnet_ids, region=region)
+
+    for subnet, subnet_id in zip(subnets, subnet_ids):
         # Verify subnet exists
         if not subnet:
             logger.error(f"Subnet with id {subnet_id} does not exist.")
@@ -162,37 +181,26 @@ def verify_aws_subnets(
             )
             return False, None
 
-        # Verify that the subnet is auto-assigning public IP addresses (we don't support private subnets atm).
-        if not subnet.map_public_ip_on_launch:
-            logger.error(
+        # Verify that the subnet is auto-assigning public IP addresses if it's not private.
+        if not is_private_network and not subnet.map_public_ip_on_launch:
+            logger.warning(
                 f"The subnet {subnet_id} does not have the 'Auto-assign Public IP' option enabled. This is not currently supported."
             )
-            return False, None
 
         # Success!
         logger.info(f"Subnet {subnet.id}'s verification succeeded.")
 
-    # Verify that each AZ has at least one subnet
-    availability_zones = set(get_availability_zones(region=region))
-    availability_zones_with_a_subnet = set(
-        subnet.availability_zone for subnet in subnets
-    )
-
-    availability_zones_without_subnet = (
-        availability_zones - availability_zones_with_a_subnet
-    )
-    if len(availability_zones_without_subnet) > 0:
-        logger.error(
-            f"{region} has availability zones: {availability_zones}. Anyscale requires a subnet in every availability zone. Please provide a subnet for each of the following availability zones: {availability_zones_without_subnet}"
+    # combine subnet and its availability zone
+    subnet_ids_with_availability_zones = [
+        SubnetIdWithAvailabilityZoneAWS(
+            subnet_id=subnet.id, availability_zone=subnet.availability_zone,
         )
-        return False, None
-
-    # @sluo / @allenyin: Why do we need this sorting?
-    reordered_subnet_ids = [
-        subnet.id
-        for subnet in sorted(subnets, key=lambda subnet: subnet.availability_zone)
+        for subnet in subnets
     ]
-    cloud_resource.aws_subnet_ids = reordered_subnet_ids
+    cloud_resource.aws_subnet_ids_with_availability_zones = (
+        subnet_ids_with_availability_zones
+    )
+    cloud_resource.aws_subnet_ids = None
 
     logger.info(f"Subnets {cloud_resource.aws_subnet_ids} verification succeeded.")
     return True, cloud_resource
@@ -226,8 +234,17 @@ def _get_roles_from_role_names(names: List[str], region: str) -> List[Any]:
     ]
 
 
+def _get_attached_policies_from_role(boto3_session: Any, role: Any) -> List[Any]:
+    iam = boto3_session.resource("iam")
+    return [
+        iam.PolicyVersion(policy.arn, policy.default_version_id)
+        for policy in role.attached_policies.all()
+    ]
+
+
 def verify_aws_iam_roles(
     cloud_resource: CreateCloudResource,
+    boto3_session: Any,
     region: str,
     anyscale_aws_account: str,
     logger: BlockLogger,
@@ -241,97 +258,63 @@ def verify_aws_iam_roles(
         AwsRoleArn.from_string(arn).to_role_name()
         for arn in cloud_resource.aws_iam_role_arns
     ]
-
     roles = _get_roles_from_role_names(names=role_names, region=region)
-    if not any((ANYSCALE_IAM_ROLE_NAME in role.role_name for role in roles)):
-        logger.error(
-            "IAM roles of this cloud resource do not contain anyscale iam role."
+
+    # verifying control plane role: anyscale iam role
+    anyscale_iam_role = roles[0]
+    assume_role_policy_document = anyscale_iam_role.assume_role_policy_document
+    if not contains_control_plane_role(
+        assume_role_policy_document=assume_role_policy_document,
+        anyscale_aws_account=anyscale_aws_account,
+    ):
+        logger.warning(
+            f"Anyscale IAM role {anyscale_iam_role.arn} does not contain expected assume role policy. It must allow assume role from arn:aws:iam::{anyscale_aws_account}:root."
         )
-        return False
-    if not any((DEFAULT_RAY_IAM_ROLE in role.role_name for role in roles)):
-        logger.error("IAM roles of this cloud resource do not contain ray iam role.")
-        return False
-
-    for role in roles:
-        if not role:
-            logger.error(f"IAM role with arn {role.arn} does not exist.")
-            return False
-
-        if ANYSCALE_IAM_ROLE_NAME in role.role_name:
-            assume_role_policy_document = role.assume_role_policy_document
-            # not verifying the statement external id condition because cloud_id is not added before cloud creation
-            if (
-                "Statement" in assume_role_policy_document
-                and len(assume_role_policy_document["Statement"]) > 0
-                and "Condition" in assume_role_policy_document["Statement"][0]
-            ):
-                del assume_role_policy_document["Statement"][0]["Condition"]
-            expected_assume_role_policy_document = get_anyscale_aws_iam_assume_role_policy(
-                anyscale_aws_account=anyscale_aws_account
+        expected_assume_role_policy_document = get_anyscale_aws_iam_assume_role_policy(
+            anyscale_aws_account=anyscale_aws_account
+        )
+        logger.warning(
+            compare_dicts_diff(
+                assume_role_policy_document, expected_assume_role_policy_document
             )
-            if assume_role_policy_document != expected_assume_role_policy_document:
-                logger.error(
-                    f"Anyscale IAM role {role.arn} does not contain expected assume role policy."
-                )
-                logger.error(
-                    compare_dicts_diff(
-                        assume_role_policy_document,
-                        expected_assume_role_policy_document,
-                    )
-                )
-                return False
+        )
 
-            for policy in role.policies.all():
-                if policy.policy_name == ANYSCALE_IAM_POLICY_NAME_STEADY_STATE:
-                    if (
-                        policy.policy_document
-                        != ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE
-                    ):
-                        logger.error(
-                            f"IAM role {role.arn} policy verification failed for policy {ANYSCALE_IAM_POLICY_NAME_STEADY_STATE}."
-                        )
-                        logger.error(
-                            compare_dicts_diff(
-                                policy.policy_document,
-                                ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE,
-                            )
-                        )
-                        return False
-                elif policy.policy_name == ANYSCALE_IAM_POLICY_NAME_INITIAL_RUN:
-                    if (
-                        policy.policy_document
-                        != ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN
-                    ):
-                        logger.error(
-                            f"IAM role {role.arn} policy verification failed for policy {ANYSCALE_IAM_POLICY_NAME_INITIAL_RUN}."
-                        )
-                        logger.error(
-                            compare_dicts_diff(
-                                policy.policy_document,
-                                ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN,
-                            )
-                        )
-                        return False
-                else:
-                    logger.info(
-                        f"Unknown policy {policy.policy_name} for IAM role {role.arn}. Skipping policies verification."
-                    )
-        elif DEFAULT_RAY_IAM_ROLE in role.role_name:
-            policy_names = [
-                policy.policy_name for policy in role.attached_policies.all()
-            ]
-            if AMAZON_ECR_READONLY_ACCESS_POLICY_NAME not in policy_names:
-                logger.error(
-                    f"Ray role {role.arn} must contain policy {AMAZON_ECR_READONLY_ACCESS_POLICY_NAME}."
-                )
-                return False
-            if AMAZON_S3_FULL_ACCESS_POLICY_NAME not in policy_names:
-                logger.error(
-                    f"Ray role {role.arn} must contain policy {AMAZON_S3_FULL_ACCESS_POLICY_NAME}."
-                )
-                return False
-        else:
-            logger.info(f"Unknown role {role.arn}. Skipping policies verification.")
+    allow_actions_expected = get_allow_actions_from_policy_document(
+        ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE
+    )
+    role_policy_documents = [
+        policy.policy_document for policy in anyscale_iam_role.policies.all()
+    ]
+    attached_policies = _get_attached_policies_from_role(
+        boto3_session, anyscale_iam_role
+    )
+    attached_policy_documents = [policy.document for policy in attached_policies]
+    list_of_allow_actions_sets = [
+        get_allow_actions_from_policy_document(policy_document)
+        for policy_document in role_policy_documents + attached_policy_documents
+    ]
+    allow_actions_provided = (
+        set.union(*list_of_allow_actions_sets) if list_of_allow_actions_sets else set()
+    )
+    allow_actions_missing = allow_actions_expected - allow_actions_provided
+    if allow_actions_missing:
+        logger.warning(
+            f"IAM role {anyscale_iam_role.arn} does not have sufficient permissions. We suggest adding these actions to ensure that cluster management works properly: {allow_actions_missing}."
+        )
+
+    # verifying data plane role: ray autoscaler role
+    cluster_node_role = roles[1]
+    policy_names = [
+        policy.policy_name for policy in cluster_node_role.attached_policies.all()
+    ]
+    if AMAZON_ECR_READONLY_ACCESS_POLICY_NAME not in policy_names:
+        logger.warning(
+            f"Dataplane role {cluster_node_role.arn} does not contain policy {AMAZON_ECR_READONLY_ACCESS_POLICY_NAME}. This is safe to ignore if you are not pulling custom Docker Images from an ECR repository."
+        )
+    if AMAZON_S3_FULL_ACCESS_POLICY_NAME not in policy_names:
+        logger.warning(
+            f"Dataplane role {cluster_node_role.arn} does not contain policy {AMAZON_S3_FULL_ACCESS_POLICY_NAME}. We suggest adding these S3 privileges to ensure logs are working properly."
+        )
 
     logger.info(f"IAM roles {cloud_resource.aws_iam_role_arns} verification succeeded.")
     return True
@@ -346,7 +329,6 @@ def verify_aws_security_groups(
         return False
 
     ec2 = boto3_session.resource("ec2")
-    # Now we only have one security group defining inbound rules.
     anyscale_security_group_arn = cloud_resource.aws_security_groups[0]
     anyscale_security_group = ec2.SecurityGroup(anyscale_security_group_arn)
     if not anyscale_security_group:
@@ -354,9 +336,11 @@ def verify_aws_security_groups(
             f"Security group with id {anyscale_security_group_arn} does not exist."
         )
         return False
-    inbound_ip_permissions = anyscale_security_group.ip_permissions
+
+    # Now we only have one security group defining inbound rules.
     # 443 is for HTTPS ingress
     # 22 is for SSH
+    inbound_ip_permissions = anyscale_security_group.ip_permissions
     expected_open_ports = [443, 22]
 
     inbound_ip_permissions_with_specific_port = [
@@ -369,6 +353,7 @@ def verify_aws_security_groups(
         if sg_rule.get("IpProtocol") == "-1":
             inbound_sg_rule_with_self.extend(sg_rule.get("UserIdGroupPairs"))
 
+    missing_open_ports = []
     for port in expected_open_ports:
         if not any(
             (
@@ -376,10 +361,12 @@ def verify_aws_security_groups(
                 for inbound_ip_permission_port in inbound_ip_permissions_with_specific_port
             )
         ):
-            logger.error(
-                f"Security group with id {anyscale_security_group_arn} does not contain inbound permission for port {port}."
-            )
-            return False
+            missing_open_ports.append(port)
+    if missing_open_ports:
+        # TODO (sluo): update the doc link to our website once the page is up.
+        logger.warning(
+            f"Security group with id {anyscale_security_group_arn} does not contain inbound permission for ports: {missing_open_ports}. These ports are used for interaction with the clusters from Anyscale UI. Please make sure to configure them according to https://docs.google.com/document/d/12QE0nZwZELvR6ocW_mDISzA568VGOQgwYXECNlvCcVk"
+        )
 
     if not any(
         sg_rule.get("GroupId") == anyscale_security_group_arn
@@ -416,6 +403,34 @@ def verify_aws_s3(
         logger.error(f"S3 object with id {cloud_resource.aws_s3_id} does not exist.")
         return False
 
+    has_correct_cors_rule = False
+    """
+    Verify CORS rules. The correct CORS rule should look like:
+    [{
+        "AllowedHeaders": [
+            "*"
+        ],
+        "AllowedMethods": [
+            "GET"
+        ],
+        "AllowedOrigins": [
+            "https://console.anyscale-staging.com"
+        ],
+        "ExposeHeaders": []
+    }]
+    """
+    for rule in s3_bucket.Cors().cors_rules:
+        assert isinstance(rule, dict), "Malformed CORS rule."
+        has_correct_cors_rule = (
+            ANYSCALE_HOST in rule.get("AllowedOrigins", [])
+            and "*" in rule.get("AllowedHeaders", [])
+            and "GET" in rule.get("AllowedMethods", [])
+        )
+
+    if not has_correct_cors_rule:
+        logger.warning(
+            f"S3 bucket {bucket_name} does not have the correct CORS rule for Anyscale. This is safe to ignore if you are not using Anyscale UI. Otherwise please create the correct CORS rule for Anyscale according to https://docs.google.com/document/d/12QE0nZwZELvR6ocW_mDISzA568VGOQgwYXECNlvCcVk"
+        )
     logger.info(f"S3 {cloud_resource.aws_s3_id} verification succeeded.")
     return True
 
