@@ -349,6 +349,9 @@ def cloud_secrets(
 @click.option(
     "--s3-bucket-id", help="S3 bucket ID.", required=False, type=str,
 )
+@click.option(
+    "--private-network", help="Use private network.", is_flag=True, default=False,
+)
 def register_cloud(
     provider: str,
     region: str,
@@ -360,6 +363,7 @@ def register_cloud(
     instance_iam_role_id: str,
     security_group_ids: str,
     s3_bucket_id: str,
+    private_network: bool,
 ) -> None:
 
     if provider == "aws":
@@ -389,6 +393,7 @@ def register_cloud(
             instance_iam_role_id=instance_iam_role_id,
             security_group_ids=security_group_ids.split(","),
             s3_bucket_id=s3_bucket_id,
+            private_network=private_network,
         )
     elif provider == "gcp":
         # TODO (allenyin): implement this
