@@ -1,11 +1,9 @@
 import datetime
 import logging
-import os
 from typing import Optional
 
 import click
 
-from anyscale.auth_proxy import make_auth_proxy_app
 from anyscale.project import get_project_id, get_project_session, load_project_or_throw
 from anyscale.shared_anyscale_utils.util import execution_log_name
 from anyscale.snapshot import copy_file
@@ -135,29 +133,6 @@ def session_finish_command(command_id: str, stop: bool, terminate: bool) -> None
     )
 
 
-# Note: These functions are not normally updated, please cc yiran or ijrsvt on changes.
-@session_cli.command(name="auth_start", help="Start the auth proxy", hidden=True)
-@click.option(
-    "--auth-token", help="Token for authentication proxy", type=str, required=False
-)
-@click.option(
-    "--user-service-token", help="Token for user service", type=str, required=False
-)
-def auth_start(auth_token: Optional[str], user_service_token: Optional[str]) -> None:
-    from aiohttp import web
-
-    # TODO(pcm): Make this required and pass in after the Docker image is migrated.
-    if not auth_token:
-        auth_token = os.environ["ANYSCALE_AUTH_TOKEN"]
-    if not user_service_token:
-        user_service_token = os.environ.get("ANYSCALE_USER_SERVICE_TOKEN")
-
-    assert auth_token, "Auth Token must be set by parameter or environment variable."
-
-    auth_proxy_app = make_auth_proxy_app(auth_token, user_service_token)
-    web.run_app(auth_proxy_app)
-
-
 @session_cli.command(
     name="web_terminal_server", help="Start the web terminal server", hidden=True
 )
