@@ -1,7 +1,9 @@
+import json
 import os
 from typing import Any
 
 import click
+import requests
 
 from anyscale.authenticate import get_auth_api_client
 from anyscale.client.openapi_client.models.create_experimental_workspace import (
@@ -28,13 +30,13 @@ ANYSCALE_WORKSPACES_SSH_OPTIONS = [
 ]
 
 
-@click.group("workspace", help="Interact with workspaces on Anyscale.", hidden=True)
+@click.group("workspace", help="Interact with workspaces on Anyscale.")
 def workspace_cli() -> None:
     pass
 
 
 @workspace_cli.command(
-    name="create", help="Create a workspace on Anyscale.", hidden=True
+    name="create", help="Create a workspace on Anyscale.",
 )
 @click.option(
     "--name", "-n", required=True, help="Name of the workspace to create.",
@@ -104,7 +106,7 @@ def create(
 
 
 @workspace_cli.command(
-    name="start", help="Start an existing workspace on Anyscale.", hidden=True
+    name="start", help="Start an existing workspace on Anyscale.",
 )
 @click.option(
     "--name", "-n", required=True, help="Name of existing workspace to start.",
@@ -133,7 +135,7 @@ def start(name: str) -> None:
 
 
 @workspace_cli.command(
-    name="terminate", help="Terminate a workspace on Anyscale.", hidden=True
+    name="terminate", help="Terminate a workspace on Anyscale.",
 )
 @click.option(
     "--name", "-n", required=True, help="Name of existing workspace to terminate.",
@@ -150,11 +152,7 @@ def terminate(name: str) -> None:
 
 @workspace_cli.command(name="clone", help="Clone a workspace on Anyscale.")
 @click.option(
-    "--name",
-    "-n",
-    required=True,
-    default=None,
-    help="Name of existing workspace to clone.",
+    "--name", "-n", required=True, help="Name of existing workspace to clone.",
 )
 def clone(name: str) -> None:
     """
@@ -273,17 +271,13 @@ def run(command: str, web_terminal: bool, as_job: bool, no_push: bool,) -> None:
     workspace_controller = WorkspaceController()
     dir_name = workspace_controller.get_workspace_dir_name()
     if web_terminal:
-        auth_api_client = get_auth_api_client()
         cluster_id = workspace_controller.get_activated_workspace().cluster_id
-        results = auth_api_client.api_client.execute_shell_command_api_v2_sessions_session_id_execute_shell_command_post(
-            cluster_id,
-            ExecuteShellCommandOptions(shell_command=f"cd ~/{dir_name} && {command}"),
-        )
+        _execute_shell_command(cluster_id, f"cd ~/{dir_name} && {command}")
         # TODO(ekl) show the workspace URL here and also block on completion.
         print()
         print(
             "Command submitted succcessfully! See the 'Command History' tab "
-            f"of this workspace to view command status and output: {results}"
+            "of this workspace to view command status and output."
         )
         print()
     else:
@@ -292,6 +286,20 @@ def run(command: str, web_terminal: bool, as_job: bool, no_push: bool,) -> None:
         )
 
 
+@workspace_cli.command(name="ssh", help="ssh into a workspace")
+def ssh() -> None:
+    """
+    ssh into a running workspace.
+    """
+    _check_local()
+
+    workspace_controller = WorkspaceController()
+    dir_name = workspace_controller.get_workspace_dir_name()
+    workspace_controller.run_cmd(
+        ANYSCALE_WORKSPACES_SSH_OPTIONS, f"cd ~/{dir_name} && /bin/bash",
+    )
+
+
 def _do_pull(pull_git_state):
     workspace_controller = WorkspaceController()
     dir_name = workspace_controller.get_workspace_dir_name()
@@ -364,3 +372,35 @@ def _exit_error(msg: str) -> None:
     print()
     print(msg)
     exit(1)
+
+
+def _execute_shell_command(cluster_id: str, shell_command: str):
+    auth_api_client = get_auth_api_client()
+
+    result = auth_api_client.api_client.execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post(
+        cluster_id, ExecuteShellCommandOptions(shell_command=shell_command),
+    ).result
+
+    command_id = result.command_id
+
+    body = {
+        "command_id": command_id,
+        "shell_command": shell_command,
+    }
+
+    body_string = json.dumps(body)
+
+    cluster = auth_api_client.api_client.get_decorated_cluster_api_v2_decorated_sessions_cluster_id_get(
+        cluster_id
+    ).result
+
+    webterminal_auth_url = cluster.webterminal_auth_url
+    index = webterminal_auth_url.index("/auth/") if webterminal_auth_url else None
+    cluster_dns_name = webterminal_auth_url[:index] if index else None
+    if not cluster_dns_name:
+        return
+
+    with requests.Session() as session:
+        session.get(webterminal_auth_url)
+        web_terminals_endpoint = f"{cluster_dns_name}/webterminal/exec"
+        session.post(web_terminals_endpoint, data=body_string)
