@@ -237,16 +237,6 @@ class ClientBuilder:
             _ignore_version_check = True
         self._ignore_version_check = _ignore_version_check
 
-        s3_caching = os.environ.get("ANYSCALE_ENABLE_S3_CACHING")
-        if s3_caching is not None and s3_caching == "1":
-            self._log.debug("Using s3 caching to start cluster.")
-            from anyscale.utils.runtime_env import (
-                runtime_env_setup as s3_runtime_env_setup,
-            )
-
-            s3_runtime_env_setup()
-            anyscale.utils.runtime_env.logger = log
-
         if os.environ.get("ANYSCALE_COMPUTE_CONFIG") == "1":
             self._log.info(
                 "All anyscale.connect clusters will be started with compute configs so "
