@@ -19,7 +19,10 @@ class ProjectBlock:
     """
 
     def __init__(
-        self, project_dir: Optional[str] = None, project_name: Optional[str] = None,
+        self,
+        project_dir: Optional[str] = None,
+        project_name: Optional[str] = None,
+        log_output: bool = True,
     ):
         """
         If project_dir is passed or exists in the directory structure: ensure the project_dir
@@ -34,8 +37,8 @@ class ProjectBlock:
                 with Anyscale. This will not be used if a registered project already exists
                 in the project_dir.
         """
-        self.log = BlockLogger()
-        auth_api_client = get_auth_api_client()
+        self.log = BlockLogger(log_output=log_output)
+        auth_api_client = get_auth_api_client(log_output=log_output)
         self.api_client = auth_api_client.api_client
         self.anyscale_api_client = auth_api_client.anyscale_api_client
         self.project_dir = (
@@ -45,13 +48,15 @@ class ProjectBlock:
         self.block_label = "Project"
         self.log.open_block(self.block_label, block_title="Choosing a project")
 
-        if self.project_dir is None:
+        if self.project_dir is None and project_name is None:
             self.project_dir = anyscale.project.find_project_root(os.getcwd())
+
+        left_pad = " " * 2
         if self.project_dir:
+            # TODO(nikita): Remove this logic when removing .anyscale.yaml in Q3 2022
             self.project_id, self.project_name = self._ensure_project_setup_at_dir(
                 self.project_dir, project_name
             )
-            left_pad = " " * 2
             self.log.info(
                 f"{left_pad}{'name:': <20}{self.project_name}",
                 block_label=self.block_label,
@@ -64,6 +69,18 @@ class ProjectBlock:
                 f"{left_pad}{'project directory:': <20}{self.project_dir}",
                 block_label=self.block_label,
             )
+        elif project_name:
+            self.project_id, self.project_name = self._create_or_get_project_from_name(
+                project_name
+            )
+            self.log.info(
+                f"{left_pad}{'name:': <20}{self.project_name}",
+                block_label=self.block_label,
+            )
+            self.log.info(
+                f"{left_pad}{'project id:': <20}{self.project_id}",
+                block_label=self.block_label,
+            )
         else:
             self.project_id, self.project_name = self._get_default_project()
         self.log.close_block(self.block_label)
@@ -103,6 +120,7 @@ class ProjectBlock:
         # If the project yaml exists, assume we're already setup.
         project_yaml = os.path.join(project_dir, ".anyscale.yaml")
         if os.path.exists(project_yaml):
+            # Validate format of project yaml and get project id
             proj_def = anyscale.project.ProjectDefinition(project_dir)
             project_id: Optional[str] = anyscale.project.get_project_id(proj_def.root)
             if not project_id:
@@ -125,8 +143,10 @@ class ProjectBlock:
 
         project_id = find_project_id(self.anyscale_api_client, project_name)
         if project_id is None:
+            # Create a new project in the local directory with given name, because
+            # project with this name doesn't exist yet.
             self.log.info(
-                f"Creating new project named {BlockLogger.highlight(project_name)} for local dir {project_dir}",
+                f"Creating new project named {BlockLogger.highlight(project_name)} for local dir {project_dir}.",
                 block_label=self.block_label,
             )
             self.log.info(
@@ -141,8 +161,10 @@ class ProjectBlock:
             )
             project_id = project_response.result.id
         else:
+            # Project already exists with this name, yet directory doesn't contain
+            # project yaml.
             self.log.info(
-                f"Connecting local directory {project_dir} to project {BlockLogger.highlight(project_name)}",
+                f"Connecting local directory {project_dir} to project {BlockLogger.highlight(project_name)}.",
                 block_label=self.block_label,
             )
             self.log.info(
@@ -156,13 +178,44 @@ class ProjectBlock:
 
         return project_id, project_name
 
+    def _create_or_get_project_from_name(self, project_name: str) -> Tuple[str, str]:
+        """
+        Get or create an Anyscale project not rooted in any directory
+        (without .anyscale.yaml).
+
+        Returns:
+        The project id and project name of the project being used.
+        """
+        project_id = find_project_id(self.anyscale_api_client, project_name)
+        if project_id is None:
+            self.log.info(
+                f"Creating new project named {BlockLogger.highlight(project_name)}.",
+                block_label=self.block_label,
+            )
+            project_response = self.anyscale_api_client.create_project(
+                {
+                    "name": project_name,
+                    "description": "Automatically created by Anyscale Connect",
+                }
+            )
+            project_id = project_response.result.id
+        self.log.info(
+            f"Using the project {BlockLogger.highlight(project_name)}:",
+            block_label=self.block_label,
+        )
+        return project_id, project_name
+
 
 def create_project_block(
-    project_dir: Optional[str] = None, project_name: Optional[str] = None
+    project_dir: Optional[str] = None,
+    project_name: Optional[str] = None,
+    log_output: bool = True,
 ):
     """
     Function to create new ProjectBlock object. The ProjectBlock object
     is not a global variable an will be reinstantiated on each call to
     get_project_block.
     """
-    return ProjectBlock(project_dir=project_dir, project_name=project_name)
+    return ProjectBlock(
+        project_dir=project_dir, project_name=project_name, log_output=log_output
+    )
