@@ -17,7 +17,7 @@ from anyscale.controllers.base_controller import BaseController
 from anyscale.project import get_project_id, get_project_session, load_project_or_throw
 import anyscale.shared_anyscale_utils.conf as shared_anyscale_conf
 from anyscale.shared_anyscale_utils.util import execution_log_name
-from anyscale.utils.import_ray_util import try_import_ray
+from anyscale.utils.imports.all import try_import_ray
 
 
 from anyscale.cluster_config import (  # noqa: N812 isort: skip
