@@ -44,23 +44,27 @@ class ExperimentalIntegrationsController(BaseController):
         cloud = self.api_client.get_cloud_api_v2_clouds_cloud_id_get(
             cloud_id=cloud_id
         ).result
-        if cloud.provider != "AWS":
-            raise click.ClickException(
-                "W&B integration is currently only supported for AWS clouds."
-            )
 
         user_id = self.api_client.get_user_info_api_v2_userinfo_get().result.id
 
         secret_name = f"wandb_api_key_{user_id}"
         cloud_region = cloud.region
-        put_secret_cmd = f"`AWS_DEFAULT_REGION={cloud_region} aws secretsmanager create-secret --name {secret_name} --secret-string {{my-wandb-api-key}}`"
+        if cloud.provider == "AWS":
+            put_secret_cmd = f"`AWS_DEFAULT_REGION={cloud_region} aws secretsmanager create-secret --name {secret_name} --secret-string {{my-wandb-api-key}}`"
+        elif cloud.provider == "GCP":
+            put_secret_cmd = f'printf "{{my-wandb-api-key}}" | gcloud secrets create {secret_name} --data-file=-'
+        else:
+            raise click.ClickException(
+                "W&B integration is currently only supported for AWS and GCP clouds."
+            )
         steps = f"""
             1. Place your W&B API key in the AWS secrets manager associated with your Anyscale cloud account. The secret key should be `{secret_name}`.
                This can be done by running {self.log.highlight(put_secret_cmd)}
-               in an environment that has access to your AWS account.
+               in an environment that can write secrets to your {cloud.provider} account.
             2. [Optional] Allow Anyscale clusters started in {cloud_name} to access your secret store for the cloud by running {self.log.highlight(f"`anyscale cloud secrets --name {cloud_name}`")}.
                This is not necessary if the organization admin already granted access.
-            3. Run a production job using ray.air.callbacks.wandb.WandbLoggerCallback in your code. No parameters need to be passed to WandbLoggerCallback to use this integration.
+            3. Run a production job or workspace using ray.air.callbacks.wandb.WandbLoggerCallback in your code. No parameters need to be passed to WandbLoggerCallback to use this integration.
+               \033[1mNote:\033[0m Please make sure to restart any existing workspace after running this command to ensure the integration is enabled.
             """
 
         try:
