@@ -21,7 +21,7 @@ from anyscale.project import (
     load_project_or_throw,
 )
 from anyscale.util import get_endpoint, humanize_timestamp
-from anyscale.utils.import_ray_util import try_import_ray
+from anyscale.utils.imports.all import try_import_ray
 
 
 class ListController(BaseController):
