@@ -20,6 +20,19 @@ from anyscale.controllers.base_controller import BaseController
 from anyscale.utils.logs_utils import LogGroup
 
 
+# Page size for listing bucket
+DEFAULT_PAGE_SIZE = 1000
+
+# Timeout for API Requests
+DEFAULT_TIMEOUT = 30
+
+# Timeout for Downloading Files
+DEFAULT_READ_TIMEOUT = 30
+
+DEFAULT_TTL = 14400
+DEFAULT_PARALLELISM = 10
+
+
 class LogsController(BaseController):
     def __init__(
         self, log: BlockLogger = BlockLogger(), initialize_auth_api_client: bool = True
@@ -61,13 +74,14 @@ class LogsController(BaseController):
         # Provide filters
         filter: LogFilter,
         # List files config
-        page_size: Optional[int],
-        ttl_seconds: Optional[int],
-        timeout: timedelta,
-        read_timeout: timedelta,
+        page_size: int = DEFAULT_PAGE_SIZE,
+        ttl_seconds: int = DEFAULT_TTL,
+        timeout: timedelta = timedelta(seconds=DEFAULT_TIMEOUT),
+        read_timeout: timedelta = timedelta(seconds=DEFAULT_READ_TIMEOUT),
         # Download config
-        parallelism: int,
+        parallelism: int = DEFAULT_PARALLELISM,
         download_dir: Optional[str] = None,
+        write_to_stdout: bool = False,
     ):
         log_chunks: List[LogFileChunk] = self._list_log_chunks(
             log_filter=filter,
@@ -86,6 +100,7 @@ class LogsController(BaseController):
             parallelism=parallelism,
             log_group=log_group,
             show_progress_bar=True,
+            write_to_stdout=write_to_stdout,
         )
 
     # TODO (shomilj): Refactor this method. It's too nested.
