@@ -213,13 +213,13 @@ class ProjectController(BaseController):
         with open(filepath, "w") as f:
             json.dump(default_config.to_dict(), f, indent=2)
 
-    def list(self, name: str, json_format: bool, any_creator: bool, max_items: int):
+    def list(self, name: str, json_format: bool, created_by_user: bool, max_items: int):
         paging_count = 20
         page_query = PageQuery(count=paging_count)
         name_query = None
         creator_query = None
 
-        if not any_creator:
+        if created_by_user:
             user_info_response = self.api_client.get_user_info_api_v2_userinfo_get()
             user_id = user_info_response.result.id
             creator_query = TextQuery(equals=user_id)
