@@ -40,7 +40,7 @@ from anyscale.utils.aws_credentials_util import (
     get_credentials_as_env_vars_from_cluster_config,
 )
 from anyscale.utils.env_utils import set_env
-from anyscale.utils.import_ray_util import try_import_ray
+from anyscale.utils.imports.all import try_import_ray
 
 
 def get_head_node_ip(cluster_config: Union[Dict[str, Any], str]) -> Any:
