@@ -13,7 +13,7 @@ from anyscale.cluster_config import configure_for_session
 from anyscale.controllers.base_controller import BaseController
 from anyscale.shared_anyscale_utils.util import get_container_name
 from anyscale.util import get_working_dir
-from anyscale.utils.import_ray_util import try_import_ray
+from anyscale.utils.imports.all import try_import_ray
 from anyscale.workspace import load_workspace_id_or_throw, write_workspace_id_to_disk
 
 
