@@ -67,7 +67,7 @@ def get_project_id(project_dir: str) -> str:
     if os.path.isfile(project_filename):
         with open(project_filename) as f:
             config = yaml.safe_load(f)
-            project_id = config["project_id"]
+            project_id = config.get("project_id")
     else:
         # TODO(pcm): Consider doing this for the user and retrying the command
         # they were trying to run.
@@ -368,6 +368,14 @@ def get_and_validate_project_id(
     return project_id
 
 
+def get_default_project(anyscale_api_client: Optional[DefaultApi] = None):
+    anyscale_api_client = (
+        anyscale_api_client or get_auth_api_client().anyscale_api_client
+    )
+    default_project = anyscale_api_client.get_default_project().result
+    return default_project
+
+
 def infer_project_id(
     project_id: Optional[str], anyscale_api_client: DefaultApi, log: BlockLogger
 ) -> str:
