@@ -24,13 +24,6 @@ from anyscale.commands.migrate_commands import migrate_cli
 from anyscale.commands.project_commands import anyscale_init, project_cli
 from anyscale.commands.schedule_commands import schedule_cli
 from anyscale.commands.service_commands import service_cli
-from anyscale.commands.session_commands import (
-    anyscale_pull,
-    anyscale_push,
-    anyscale_ssh,
-    anyscale_start,
-    anyscale_stop,
-)
 from anyscale.commands.session_commands_hidden import session_cli
 from anyscale.commands.workspace_commands import workspace_cli
 import anyscale.conf
@@ -120,12 +113,7 @@ cli.add_command(experimental_integrations_cli)
 cli.add_command(auth_cli)
 
 cli.add_command(anyscale_init)
-cli.add_command(anyscale_stop)
-cli.add_command(anyscale_ssh)
-cli.add_command(anyscale_start)
 cli.add_command(anyscale_exec)
-cli.add_command(anyscale_pull)
-cli.add_command(anyscale_push)
 cli.add_command(anyscale_help)
 cli.add_command(cluster_compute_cli)
 
