@@ -34,6 +34,9 @@ EFS_TYPE = os.environ.get("ANYSCALE_EXPERIMENTAL_EFS_TYPE", "")
 # Override with container-defined IP.
 CUSTOM_EFS_IP = os.environ.get("CUSTOM_EFS_IP", "")
 CUSTOM_EFS_ROOT = os.environ.get("CUSTOM_EFS_ROOT", "")
+IDLE_TERMINATION_DIR = os.environ.get(
+    "IDLE_TERMINATION_DIR", "/tmp/anyscale/idle_termination_reports"
+)
 if CUSTOM_EFS_IP:
     EFS_IP = CUSTOM_EFS_IP
 
@@ -220,30 +223,69 @@ def do_snapshot(auto: bool = False):
 
     Can be run via `python -m anyscale.snapshot_util snapshot`.
     """
-    workspace_dir = os.path.join(EFS_WORKSPACE_DIR, WORKSPACE_ID)
-    snapshot_dir = os.path.join(workspace_dir, "snapshots")
-    # TODO(ekl) should we isolate the objects by workspace or repo?
-    optimize_git_repo(WORKING_DIR, EFS_OBJECTS_DIR)
-    zip = get_or_create_snapshot_zip(WORKING_DIR, auto)
 
-    # If the zip was already on EFS, we're done.
-    if zip.startswith(snapshot_dir):
-        return
+    try:
+        workspace_dir = os.path.join(EFS_WORKSPACE_DIR, WORKSPACE_ID)
+        snapshot_dir = os.path.join(workspace_dir, "snapshots")
+
+        is_empty = len(os.listdir(WORKING_DIR)) == 0
+
+        # directory is empty, no need to snapshot
+        if is_empty:
+            return
+
+        # TODO(ekl) should we isolate the objects by workspace or repo?
+        optimize_git_repo(WORKING_DIR, EFS_OBJECTS_DIR)
+        zip = get_or_create_snapshot_zip(WORKING_DIR, auto)
+
+        # If the zip was already on EFS, we're done.
+        if zip.startswith(snapshot_dir):
+            return
+
+        # Otherwise, move the zip into EFS along with its md5 file.
+        os.makedirs(snapshot_dir, exist_ok=True)
+        shutil.move(zip, os.path.join(snapshot_dir, os.path.basename(zip)))
+        shutil.move(
+            zip + ".md5", os.path.join(snapshot_dir, os.path.basename(zip) + ".md5")
+        )
+        for config in CONFIGS_TO_SAVE:
+            source = os.path.join("/home/ray", config)
+            if os.path.exists(source):
+                shutil.copy(source, os.path.join(workspace_dir, config))
+
+        # report successful idle termination status
+        report_idle_termination_activity()
+
+    except Exception:
+        logger.exception("Failed to create a snapshot")
+        # report error idle termination status
+        report_idle_termination_error("Failed to create a snapshot")
 
-    # Otherwise, move the zip into EFS along with its md5 file.
-    os.makedirs(snapshot_dir, exist_ok=True)
-    shutil.move(zip, os.path.join(snapshot_dir, os.path.basename(zip)))
-    shutil.move(
-        zip + ".md5", os.path.join(snapshot_dir, os.path.basename(zip) + ".md5")
-    )
-    for config in CONFIGS_TO_SAVE:
-        source = os.path.join("/home/ray", config)
-        if os.path.exists(source):
-            shutil.copy(source, os.path.join(workspace_dir, config))
     if AUTOGC:
         gc_snapshots()
 
 
+def report_idle_termination_activity():
+    if os.path.exists(IDLE_TERMINATION_DIR):
+        with open(f"{IDLE_TERMINATION_DIR}/workspace.json", "w") as f:
+            f.write(json.dumps({"last_activity_timestamp": time.time()}))
+    else:
+        logger.warning(
+            f"Did not report workspace idle termination status because {IDLE_TERMINATION_DIR} is not mounted."
+        )
+
+
+def report_idle_termination_error(err: str):
+    content = {"error": err}
+    if os.path.exists(IDLE_TERMINATION_DIR):
+        with open(f"{IDLE_TERMINATION_DIR}/workspace.json", "w") as f:
+            f.write(json.dumps(content))
+    else:
+        logger.warning(
+            f"Did not report workspace idle termination status because {IDLE_TERMINATION_DIR} is not mounted."
+        )
+
+
 def gc_snapshots() -> None:
     """Garbage collect snapshots older than 1 hr.
 
@@ -615,6 +657,9 @@ def setup_nfs():
         except Exception:
             logger.exception(f"Error running {cmd}")
 
+    # on first load, report an activity to signal healthy start
+    report_idle_termination_activity()
+
 
 def setup_vscode_desktop():
     local_folder = "/home/ray/.vscode-server"
