@@ -459,7 +459,15 @@ def wait_for_session_start(
             if len(sessions) > 0:
                 session = sessions[0]
 
-                if session.state == "Running" and session.pending_state is None:
+                # TODO: Remove "session.host_name" check once https://github.com/anyscale/product/issues/15502 is fixed
+                # A cluster may have "running" state while its dns is not set up yet. When DNS is not ready,
+                # many cluster operations, like ray job submission will fail. So we wait until DNS info
+                # is ready.
+                if (
+                    session.state == "Running"
+                    and session.pending_state is None
+                    and session.host_name
+                ):
                     return cast(str, session.id)
 
                 # Check for start up errors
@@ -745,8 +753,7 @@ def _check_python_version(python_version: str) -> None:
 
 
 def sleep_till(wake_time: float) -> None:
-    """ Sleep till the designated time
-    """
+    """Sleep till the designated time"""
     time.sleep(max(0, wake_time - time.time()))
 
 
@@ -755,7 +762,7 @@ def poll(
     timeout_secs: Optional[float] = None,
     max_iter: Optional[int] = None,
 ) -> Generator[int, None, None]:
-    """ Poll every interval_secs, until timeout_secs, or max iterations has been reached.
+    """Poll every interval_secs, until timeout_secs, or max iterations has been reached.
     Yield the iteration number, starting at 1.
     """
     last_poll_time = time.time()
@@ -960,3 +967,52 @@ def populate_dict_with_workspace_config_if_exists(
             ):
                 config_dict["compute_config_id"] = cluster.cluster_compute_id
     return config_dict
+
+
+def get_allow_actions_from_policy_document(policy_document: Dict[Any, Any]) -> set:
+    allow_actions = {
+        action
+        for statement in (
+            policy_document["Statement"]
+            if isinstance(policy_document["Statement"], list)
+            else [policy_document["Statement"]]
+        )
+        for action in (
+            statement["Action"]
+            if isinstance(statement["Action"], list)
+            else [statement["Action"]]
+        )
+        if statement["Effect"] == "Allow"
+    }
+    return allow_actions
+
+
+def contains_control_plane_role(
+    assume_role_policy_document: Dict[Any, Any], anyscale_aws_account: str
+) -> bool:
+    for statement in (
+        assume_role_policy_document["Statement"]
+        if isinstance(assume_role_policy_document["Statement"], list)
+        else [assume_role_policy_document["Statement"]]
+    ):
+        if (
+            statement["Effect"] == "Allow"
+            and statement.get("Action") == "sts:AssumeRole"
+        ):
+            for principal in (
+                statement["Principal"]
+                if isinstance(statement["Principal"], list)
+                else [statement["Principal"]]
+            ):
+                if "AWS" in principal:
+                    for aws_account in (
+                        principal["AWS"]
+                        if isinstance(principal["AWS"], list)
+                        else [principal["AWS"]]
+                    ):
+                        if aws_account in (
+                            f"arn:aws:iam::{anyscale_aws_account}:root",
+                            anyscale_aws_account,
+                        ):
+                            return True
+    return False
