@@ -629,8 +629,12 @@ def test_list_cloud(cloud_id: Optional[str], cloud_name: Optional[str]) -> None:
     ],
 )
 @pytest.mark.parametrize("verify_success", [True, False])
+@pytest.mark.parametrize("private_network", [True, False])
 def test_register_cloud(
-    anyscale_iam_role: str, anyscale_instance_role: str, verify_success: bool
+    anyscale_iam_role: str,
+    anyscale_instance_role: str,
+    verify_success: bool,
+    private_network: bool,
 ) -> None:
 
     mock_cloud = Mock(result=Mock(id="mock_cloud_id"))
@@ -647,7 +651,7 @@ def test_register_cloud(
     mock_get_role = Mock()
 
     with patch(
-        "anyscale.controllers.cloud_controller.CloudController.verifiy_aws_cloud_resources",
+        "anyscale.controllers.cloud_controller.CloudController.verify_aws_cloud_resources",
         new=Mock(return_value=verify_success),
     ), patch.multiple(
         "anyscale.controllers.cloud_controller",
@@ -668,6 +672,7 @@ def test_register_cloud(
                 instance_iam_role_id=anyscale_instance_role,
                 security_group_ids=mock_security_group_ids,
                 s3_bucket_id=mock_s3_bucket_id,
+                private_network=private_network,
             )
         else:
             with pytest.raises(ClickException):
@@ -681,6 +686,7 @@ def test_register_cloud(
                     instance_iam_role_id=anyscale_instance_role,
                     security_group_ids=mock_security_group_ids,
                     s3_bucket_id=mock_s3_bucket_id,
+                    private_network=private_network,
                 )
     mock_get_role.assert_called_once_with("mock_anyscale_role", mock_region)
 
@@ -691,6 +697,7 @@ def test_register_cloud(
             credentials=anyscale_iam_role,
             name=mock_cloud_name,
             is_bring_your_own_resource=True,
+            is_private_cloud=private_network,
         )
     )
 
@@ -748,6 +755,7 @@ def test_verify_cloud(
                 cloud_resource=cloud_resource_mock,
                 provider=cloud_provider,
                 is_bring_your_own_resource=is_bring_your_own_resource,
+                is_private_cloud=False,
             )
         )
         cloud_controller.api_client.get_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_get = Mock(
@@ -774,6 +782,7 @@ def test_verify_cloud(
             verify_aws_subnets_mock.assert_called_once_with(
                 cloud_resource=cloud.result.cloud_resource,
                 region=cloud.result.region,
+                is_private_network=False,
                 logger=cloud_controller.log,
                 ignore_capacity_errors=False,
             )
