@@ -219,8 +219,10 @@ def test_write_sample_compute_config(
 
 @pytest.mark.parametrize("name", ["", "project_a"])
 @pytest.mark.parametrize("json_format", [True, False])
-@pytest.mark.parametrize("any_creator", [True, False])
-def test_list(mock_auth_api_client, name: str, json_format: bool, any_creator: bool):
+@pytest.mark.parametrize("created_by_user", [True, False])
+def test_list(
+    mock_auth_api_client, name: str, json_format: bool, created_by_user: bool
+):
 
     project_controller = ProjectController()
     mock_creator_id = "usr_abc"
@@ -256,12 +258,12 @@ def test_list(mock_auth_api_client, name: str, json_format: bool, any_creator: b
     mock_search_projects = Mock(return_value=mock_response)
     project_controller.anyscale_api_client.search_projects = mock_search_projects
 
-    project_controller.list(name, json_format, any_creator, max_items=20)
+    project_controller.list(name, json_format, created_by_user, max_items=20)
 
-    if any_creator:
-        project_controller.api_client.get_user_info_api_v2_userinfo_get.assert_not_called()
-    else:
+    if created_by_user:
         project_controller.api_client.get_user_info_api_v2_userinfo_get.assert_called_once_with()
+    else:
+        project_controller.api_client.get_user_info_api_v2_userinfo_get.assert_not_called()
 
     project_controller.anyscale_api_client.search_projects.assert_called_once()
     (
@@ -271,10 +273,10 @@ def test_list(mock_auth_api_client, name: str, json_format: bool, any_creator: b
         assert projects_query.name.equals == name
     else:
         assert projects_query.name is None
-    if any_creator:
-        assert projects_query.creator_id is None
-    else:
+    if created_by_user:
         assert projects_query.creator_id.equals == mock_creator_id
+    else:
+        assert projects_query.creator_id is None
     assert projects_query.paging.count == 20
     assert projects_query.paging.paging_token is None
 
