@@ -1,6 +1,7 @@
 import os
 from unittest.mock import ANY, Mock, mock_open, patch
 
+import click
 import pytest
 
 from anyscale.client.openapi_client.models.project import Project
@@ -11,6 +12,7 @@ from anyscale.client.openapi_client.models.session_list_response import (
 )
 from anyscale.project import (
     create_new_proj_def,
+    get_and_validate_project_id,
     get_proj_id_from_name,
     get_proj_name_from_id,
     get_project_session,
@@ -18,6 +20,7 @@ from anyscale.project import (
     ProjectDefinition,
     register_or_attach_to_project,
 )
+from anyscale.util import PROJECT_NAME_ENV_VAR
 
 
 def test_get_project_sessions(session_test_data: Session) -> None:
@@ -164,3 +167,77 @@ def test_register_or_attach_to_project_attach_to_existing(
         project_test_data.name
     )
     mock_api_client.create_project_api_v2_projects_post.assert_not_called()
+
+
+def test_get_and_validate_project_id():
+
+    # Test passing in project id
+    with patch.multiple(
+        "anyscale.project", validate_project_id=Mock(),
+    ):
+        assert (
+            get_and_validate_project_id(
+                project_id="mock_project_id1",
+                project_name=None,
+                api_client=Mock(),
+                anyscale_api_client=Mock(),
+            )
+            == "mock_project_id1"
+        )
+
+    # Test passing in project name
+    mock_get_proj_id_from_name = Mock(return_value="mock_project_id1")
+    with patch.multiple(
+        "anyscale.project",
+        validate_project_id=Mock(),
+        get_proj_id_from_name=mock_get_proj_id_from_name,
+    ):
+        assert (
+            get_and_validate_project_id(
+                project_id=None,
+                project_name="mock_project_name1",
+                api_client=Mock(),
+                anyscale_api_client=Mock(),
+            )
+            == "mock_project_id1"
+        ), "mock_cluster_name1"
+
+    # Test using default project
+    anyscale_api_client = Mock()
+    anyscale_api_client.get_default_project = Mock(
+        return_value=Mock(result=Mock(id="mock_project_id2"))
+    )
+    with patch.multiple(
+        "anyscale.project",
+        load_project_or_throw=Mock(side_effect=click.ClickException("")),
+    ):
+        assert (
+            get_and_validate_project_id(
+                project_id=None,
+                project_name=None,
+                api_client=Mock(),
+                anyscale_api_client=anyscale_api_client,
+            )
+            == "mock_project_id2"
+        )
+
+    # Test getting project_name from env var
+    mock_get_proj_id_from_name = Mock(return_value="mock_project_id3")
+    api_client = Mock()
+    with patch.multiple(
+        "anyscale.project",
+        validate_project_id=Mock(),
+        get_proj_id_from_name=mock_get_proj_id_from_name,
+    ), patch.dict(os.environ, {PROJECT_NAME_ENV_VAR: "project_from_env"}):
+        assert (
+            get_and_validate_project_id(
+                project_id=None,
+                project_name=None,
+                api_client=api_client,
+                anyscale_api_client=Mock(),
+            )
+            == "mock_project_id3"
+        )
+        mock_get_proj_id_from_name.assert_called_once_with(
+            "project_from_env", api_client
+        )
