@@ -24,6 +24,15 @@ from anyscale.util import (
     str_data_size,
     updating_printer,
 )
+from frontend.cli.anyscale.aws_iam_policies import (
+    ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE,
+    DEFAULT_RAY_IAM_ASSUME_ROLE_POLICY,
+    get_anyscale_aws_iam_assume_role_policy,
+)
+from frontend.cli.anyscale.util import (
+    contains_control_plane_role,
+    get_allow_actions_from_policy_document,
+)
 
 
 def test_updating_printer() -> None:
@@ -226,8 +235,7 @@ def test_python_version_major_minor(python_version, exception_substr):
 
 
 def test_poll():
-    """Test the poll function.
-    """
+    """Test the poll function."""
 
     end_time = time.time() + 0.5
     sleep_till(end_time)
@@ -657,6 +665,12 @@ Outputs:
     Description: Anyscale managed EFS
     Value: !Ref EFS
 
+  EFSMountTargetIP:
+    Description: Anyscale managed EFS mount target
+    Value: !GetAtt
+      - EFSMountTarget
+      - IpAddress
+
   AnyscaleIAMRole:
     Description: ARN of the cross-account IAM role
     Value: !GetAtt
@@ -786,3 +800,155 @@ def test_populate_dict_method_in_workspace(config_dict: Dict[str, Any]):
 
     # The values from the original dict takes priority
     assert dict(parsed_config, **original_dict) == updated_dict
+
+
+@pytest.mark.parametrize(
+    "policy_document,expected_actions",
+    [
+        pytest.param(
+            ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE,
+            {
+                "iam:PassRole",
+                "iam:GetInstanceProfile",
+                "ec2:DescribeAvailabilityZones",
+                "ec2:DescribeInstanceTypes",
+                "ec2:DescribeRegions",
+                "ec2:DescribeInstances",
+                "ec2:DescribeSubnets",
+                "ec2:DescribeRouteTables",
+                "ec2:DescribeSecurityGroups",
+                "ec2:RunInstances",
+                "ec2:StartInstances",
+                "ec2:StopInstances",
+                "ec2:TerminateInstances",
+                "ec2:CreateTags",
+                "ec2:DeleteTags",
+                "ec2:CancelSpotInstanceRequests",
+                "ec2:ModifyImageAttribute",
+                "ec2:ModifyInstanceAttribute",
+                "ec2:RequestSpotInstances",
+                "ec2:AttachVolume",
+                "ec2:CreateVolume",
+                "ec2:DescribeVolumes",
+                "ec2:AssociateIamInstanceProfile",
+                "ec2:DisassociateIamInstanceProfile",
+                "ec2:ReplaceIamInstanceProfileAssociation",
+                "ec2:CreatePlacementGroup",
+                "ec2:AllocateAddress",
+                "ec2:ReleaseAddress",
+                "ec2:DescribeIamInstanceProfileAssociations",
+                "ec2:DescribeInstanceStatus",
+                "ec2:DescribePlacementGroups",
+                "ec2:DescribePrefixLists",
+                "ec2:DescribeReservedInstancesOfferings",
+                "ec2:DescribeSpotInstanceRequests",
+                "ec2:DescribeSpotPriceHistory",
+                "elasticfilesystem:DescribeMountTargets",
+            },
+        ),
+        pytest.param(DEFAULT_RAY_IAM_ASSUME_ROLE_POLICY, {"sts:AssumeRole"},),
+        pytest.param(
+            {
+                "Version": "2012-10-17",
+                "Statement": [
+                    {
+                        "Effect": "Allow",
+                        "Principal": {"Service": ["ec2.amazonaws.com"]},
+                        "Action": ["sts:AssumeRole", "sts:AssumeRole"],
+                    },
+                    {
+                        "Effect": "Allow",
+                        "Principal": {"Service": ["ec2.amazonaws.com"]},
+                        "Action": ["sts:AssumeRole", "sts:AssumeRole"],
+                    },
+                ],
+            },
+            {"sts:AssumeRole"},
+        ),
+        pytest.param(
+            {
+                "Version": "2012-10-17",
+                "Statement": [
+                    {
+                        "Effect": "Deny",
+                        "Principal": {"Service": ["ec2.amazonaws.com"]},
+                        "Action": ["sts:AssumeRole", "sts:AssumeRole"],
+                    },
+                    {
+                        "Effect": "Deny",
+                        "Principal": {"Service": ["ec2.amazonaws.com"]},
+                        "Action": ["sts:AssumeRole", "sts:AssumeRole"],
+                    },
+                ],
+            },
+            set(),
+        ),
+    ],
+)
+def test_get_allow_actions_from_policy_document(policy_document, expected_actions):
+    actions = get_allow_actions_from_policy_document(policy_document=policy_document)
+    assert actions == expected_actions
+
+
+@pytest.mark.parametrize(
+    "assume_role_policy_document,expected_result",
+    [
+        pytest.param(
+            {
+                "Version": "2012-10-17",
+                "Statement": [
+                    {
+                        "Effect": "Allow",
+                        "Principal": {"AWS": "000000"},
+                        "Action": "sts:AssumeRole",
+                    },
+                ],
+            },
+            True,
+        ),
+        pytest.param(
+            get_anyscale_aws_iam_assume_role_policy(anyscale_aws_account="000000"),
+            True,
+        ),
+        pytest.param(
+            {
+                "Statement": [
+                    {
+                        "Effect": "Allow",
+                        "Principal": {
+                            "AWS": [
+                                "arn:aws:iam::other_account",
+                                "arn:aws:iam::000000:root",
+                            ]
+                        },
+                        "Action": "sts:AssumeRole",
+                    },
+                ],
+            },
+            True,
+        ),
+        pytest.param(
+            {
+                "Statement": [
+                    {
+                        "Effect": "Allow",
+                        "Principal": {
+                            "AWS": [
+                                "arn:aws:iam::other_account",
+                                "arn:aws:iam::another_account:root",
+                            ]
+                        },
+                        "Action": "sts:AssumeRole",
+                    },
+                ],
+            },
+            False,
+        ),
+    ],
+)
+def test_contains_control_plane_role(assume_role_policy_document, expected_result):
+    result = contains_control_plane_role(
+        assume_role_policy_document=assume_role_policy_document,
+        anyscale_aws_account="000000",
+    )
+    assert result == expected_result
